/*
* Copyright (C) 1995   Template Graphics Software, Inc.
_______________________________________________________________________
_________________  TEMPLATE GRAPHICS SOFTWARE INC.  ___________________
|
|
|	This class provides an abstraction of an IVF viewer object. The
|	interface to the viewer is defined by a set of virtual functions.
|
|   Author(s): James R. Gambale, Jr.
|
_________________  TEMPLATE GRAPHICS SOFTWARE INC.  ___________________
_______________________________________________________________________
*/


#ifndef __IVFVWR_H__
#define __IVFVWR_H__

class CIvfView ;
class SoWinComponent ;

class CIvfVwr : public CObject
{
public:
	CIvfVwr() ;
	DECLARE_DYNCREATE(CIvfVwr) ;
	
	~CIvfVwr() ;

	// This method stores the pointer to the IVF view object that
	// contains this viewer.
	virtual void			SetIvfView(CIvfView *pView) { m_pIvfView = pView;};
	
	// This method is invoked by the IVF view object to create the
	// viewer.
	virtual void 			CreateViewer(void *pVwrArgs);

	// This method is invoked to destroy the viewer.
	virtual void			DestroyViewer() ;

	// This method notifies the viewer that the scene graph has
	// changed.
	virtual void			SceneGraphChanged() ;

	// This method notifies the viewer that the frame title needs
	// to be updated.
	virtual BOOL			OnUpdateFrameTitle(CString &strTitle) ;

	// This method notifies the viewer that the viewer window needs
	// to be painted.
	virtual void			OnPaint() ;

	// This method is invoked during the intial update of the viewer
	// window.
	virtual void			OnInitialUpdate() ;

	// This method is invoked prior to deactivation of the viewer
	// window.
	virtual void			OnDeactivateView() ;

	// This method is invoked prior to activation of the viewer
	// window.
	virtual void			OnActivateView() ;

	// This method is invoked prior to destruction of the viewer
	// window.
	virtual void			OnDestroy() ;
	
	// This method passes command messages to the viewer.  If the
	// processes the command, TRUE is returned, FALSE is returned
	// otherwise.
	virtual BOOL			OnCommand(WPARAM wParam, LPARAM lParam);


	// This method passes messages for pretranslation to the viewer.  
	// The viewer then uses IsDialogMessage to dispatch the message
	// to any dialogs.  If the message is processed by a dialog,
	// TRUE is returned, FALSE otherwise.
	virtual BOOL			PreTranslateMessage(MSG *pMsg) ;

	virtual SoWinComponent *GetVwrComponent() ;

	virtual BOOL			OnCmdMsg(UINT nID, int nCode, void* pExtra,
			                 		 AFX_CMDHANDLERINFO* pHandlerInfo);


protected:
	// pointer to the IVF view that contains this viewer
	CIvfView *		m_pIvfView ;

} ;

#endif
